# User guide

## Installation

You can install this from PyPI.

```console
pip install atsphinx-linebreak
```

## Usage

Add `extensions` of your `conf.py`.

```python

extensions = [
    # ... other extensions ...
    "atsphinx.linebreak",  # <- ADD!
    # ... other extensions ...
]
```

## Configuration

This extension does not have configuration for behavior.
